get_data <- function(path_to_csv) {
  human_data <- read.csv(path_to_csv,numerals ="no.loss",stringsAsFactors=FALSE)
  # It's convenient to have a single identifier for each individual sequence; each participant sees
  # each sequence only once, so we can concatenate them to get a global sequence ID.
  human_data <- human_data %>% mutate(trial_id=paste(ID,Sequence,sep="_"))
  # Guarantee that within a given trial the judgments are ordered for easier
  # downstream model eval
  human_data <- human_data[order(human_data$trial_id,human_data$Number_in_seq),]
}

# Converts strings to sequences of integers
proc_seq_helper <- function(s,f) {
  len <- nchar(s)
  cs <- rep(-1,len)
  for(i in 1:nchar(s)) {
    cs[i] <- f(strtoi(substr(s,i,i)))
  }
  return(cs)
}

# Returns a sequence of integers denoting whether a cause occurs (1) or
# or does not (0) in the corresponding index of the sequence.
cause_from_seq <- function(s) {
  proc_seq_helper(s,function(x) {(x+1) %% 2})
}

# As cause_from_seq, but for the effect variable.
eff_from_seq <- function(s) {proc_seq_helper(s,function(x) {
  if(x==0 || x==3) 1 else 0})
}

# Plots participant judgments.
plot_seq <- function(seq,sdf) {
  p<-ggplot(data=sdf, aes(x=Number_in_seq, y=Correlation_estimate)) +
    ggtitle(seq) + 
    theme_minimal() +
    theme(plot.title = element_text(hjust = 0.5)) +
    geom_bar(stat="identity") + ylim(-100,100) + geom_line(data=sdf,aes(x=Number_in_seq,y=Correlation_estimate))
  print(p)
}

# Plotting bit
plot_model_vs_people <- function(title_str,human_df,model_df) {
  p<-ggplot() + 
    theme_minimal() +
    # TODO/TIA: This paste appears to be necessary. Do you know why?
    ggtitle(paste(title_str)) +
    theme(plot.title = element_text(hjust = 0.5)) +
    geom_line(data=human_df,aes(x=Number_in_seq,y=Correlation_estimate)) + ylim(-100,100) +
    geom_point(data=model_df,aes(x=i,y=model_preds))
    print(p)
}

run_test <- function(test_results,test_name,test_bool,failure_message) {
  test_results <- rbind(test_results,data.frame(test_name=test_name,passed=test_bool,
                                  message=if(test_bool) {"SUCCESS"} else {failure_message}))
  test_results
}
